@@ -9,6 +9,9 @@ from .constants import *
 dotenv_path = find_dotenv()
 load_dotenv(dotenv_path)
 credentials =  Credentials.from_service_account_file(BIG_QUERY_SERVICE_ACCOUNT_CRED)
+
+
+
 client = bigquery.Client(
     credentials=credentials,
     project=credentials.project_id,
@@ -19,9 +22,9 @@ client = bigquery.Client(
 def insert_rows_array_in_bigquery(dataset=None, table=None, rows_to_insert=None):
     try:
 
-        dataset_ref = client.dataset(dataset)
-        table_ref = dataset_ref.table(table)
-        table = client.get_table(table_ref)
+        os.environ["GOOGLE_APPLICATION_CREDENTIALS"] = BIG_QUERY_SERVICE_ACCOUNT_CRED
+        client = bigquery.Client()
+        table = f'{WRITE_BIG_QUERY_PROJECT}.{dataset}.{table}'
         rows_to_insert = rows_to_insert
         errors = client.insert_rows_json(table, rows_to_insert)
         assert errors == []
@@ -34,7 +37,7 @@ def insert_rows_in_bigquery(dataset=None, table=None, rows_to_insert=None):
     try:
         os.environ["GOOGLE_APPLICATION_CREDENTIALS"] = BIG_QUERY_SERVICE_ACCOUNT_CRED
         client = bigquery.Client()
-        table_id =  f'{BIG_QUERY_PROJECT}.{dataset}.{table}'
+        table_id =  f'{WRITE_BIG_QUERY_PROJECT}.{dataset}.{table}'
         table = client.get_table(table_id)
         errors = client.insert_rows(table, rows_to_insert)
         if errors == []:
@@ -52,7 +55,7 @@ def insert_rows_in_bigquery(dataset=None, table=None, rows_to_insert=None):
 def get_bigquery_data_from_query(query=None):
     try:
         if query:
-            df = gbq.read_gbq(query=query, project_id=BIG_QUERY_PROJECT, credentials=credentials )
+            df = gbq.read_gbq(query=query, project_id=READ_BIG_QUERY_PROJECT, credentials=credentials )
             return df
         else:
             return "Query is None"
@@ -62,7 +65,7 @@ def get_bigquery_data_from_query(query=None):
 
 def dump_dataframe_to_bigquery_table(dataset=None, table=None, dataframe=None, mode="append"):
     try:
-        gbq.to_gbq(dataframe, dataset + "." + table, BIG_QUERY_PROJECT, if_exists=mode, credentials=credentials)
+        gbq.to_gbq(dataframe, dataset + "." + table, WRITE_BIG_QUERY_PROJECT, if_exists=mode, credentials=credentials)
         print("Appending Done")
     except Exception as e:
         print(str(e))
